## Release Notes for 1.6

Released on 20 February 2022

This release does not introduce any major new features, but is instead a collection of minor improvements and tweaks based on user requests. There are also a number of changes under the hood to improve the structure and performance of novelWriter.

Some key improvements to the user interface are:

✓ The max text width setting in Preferences now also applies to the document viewer, and the setting itself on the Preference dialog has been simplified a bit.

✓ When text is selected in the document editor, the number of words selected is displayed in the editor's footer area.

✓ The search tool in the document editor now shows the number of results in the document.

✓ The Enter and Ctrl+O keyboard shortcuts should now work the same way in all tree views.

✓ It is now possible to set a blank section title format on the Build Novel Project tool and get empty paragraphs in the output. Previously, a blank format would just remove the section break entirely. This change allows the user to define hard and soft scene breaks using level three and four headings. The scene and section titles can be hidden completely with two new switches added to the user interface.

Other feature changes include:

✓ The project index is now automatically rebuilt in the event it is empty or incomplete when the project is opened.

✓ The user can now add their own syntax and GUI theme files in the app folder in their user area on the host operating system. Where the custom files must be added is described in the documentation.

✓ A Windows installer is yet again provided for novelWriter. If you have novelWriter installed using another method, make sure you uninstall it properly first as the two methods are not compatible.

✓ Release versions for Ubuntu 21.04 have been dropped, and added for the upcoming Ubuntu 22.04.

✓ Most translations have been updated. A Dutch translation is in the works.

See also the Releases page.

## Patch Notes

### Patch 1.6.1 – 16 March 2022

This is a bugfix and patch release that fixes two recursion/loop issues. One would potentially cause a crash if the window was resized rapidly, and one would cause a hang with certain search parameters in the editor's search box. The Latin American Spanish translation has also been updated.

### Patch 1.6.2 – 20 March 2022

This is a bugfix release that fixes a couple of minor issues. Projects containing one or more empty documents would trigger a rebuild of the index each time the project was opened. This has now been fixed. Another fix resolves an error message being written to the console logging output when a new document was created. Both errors were harmless.

### Patch 1.6.3 – 18 August 2022

This is a bugfix release that fixes a rare problem causing novelWriter to crash if the spell checker language setting was configured to an empty value.

A few other minor issues have also been fixed: The project language setting is now properly exported to ODT documents. Spaces are no longer inserted automatically in front of colons in certain meta data settings when the feature is enabled (it is primarily used for French). Lastly, the slider splitting the editor and viewer panels can no longer be dragged until the viewer disappears. It was not necessarily obvious how the viewer panel could be restored in such cases.

### Patch 1.6.4 – 29 September 2022

This is a bugfix release that fixes a critical bug in the insert non-breaking spaces feature. It basically no longer worked in the 1.6.3 release. This release also fixes a minor issue where the text cursor sometimes disappears when reaching the right-hand edge of the text editor window.

### Patch 1.6.5 – 13 October 2022

This is a bugfix release that fixes a a few minor issues. The idle time for new projects would be artificially inflated as the clock was not reset when the project was first created. This only affects the first entry in the writing statistics. A scaling issue for the Preferences dialog has also been fixed. It only affected screens with UI scaling enabled. Lastly, typing Shift+Enter in the text editor now creates a regular line break instead of a special line separator. The line separator serves no purpose in plain text, and was producing inconsistencies in how text is processed and displayed.